pub struct CheckpointSettings {
pub check_delay: Duration,
pub minimum_changes: usize,
pub shutdown_flag: Arc<AtomicBool>,
}Expand description
Configuration settings for the provided ExtractDb::background_checkpoints.
Examples
use std::sync::Arc;
use std::sync::atomic::{AtomicBool, Ordering};
use std::time::Duration;
use extractdb::{CheckpointSettings, ExtractDb};
let shutdown_flag = Arc::new(AtomicBool::new(false));
let mut save_settings = CheckpointSettings::new(shutdown_flag.clone());
save_settings.minimum_changes = 30;
// Checks every 5 seconds for >=30 changes.
save_settings.check_delay = Duration::from_secs(5);
// Gracefully shutdown a background thread
shutdown_flag.store(true, Ordering::Relaxed);Fields
check_delay: DurationInterval at which the internal_count is checked
e.g. Check the number of pushes every X seconds.
minimum_changes: usizeMinimum number of changes from the last disk write needed for a new disk write.
e.g. Write to disk after 200 push insertions.
shutdown_flag: Arc<AtomicBool>A flag to safely shut down the internal watcher thread. Use this to gracefully shutdown & save state
Implementations
Sourceimpl CheckpointSettings
impl CheckpointSettings
Sourcepub fn new(shutdown_flag: Arc<AtomicBool>) -> Self
pub fn new(shutdown_flag: Arc<AtomicBool>) -> Self
Generic default settings for auto-saving in ExtractDb::background_checkpoints.